// dialog.js

// Self called function to start on file include
(() => {
	$('.ui-dialog-content').on("dialogopen", function(e, ui) {
		// Add tooltip on dialog after openning to avoid bug
		setTooltip($(this).closest('.ui-dialog'));
		
		// Handle user messages
		$('#dialog-messages').children().each(function()
		{
			fadeUserMessage($(this));
		});
	});

	
})();

function updateGesaProgressBar()
{
	const progressbar = $('#progressbar');
	const options = {
		complete: function() {
			$('.progress-label', progressbar).text(globals.lang['UPDATE_COMPLETED']);
		}
	};

	setProgressBar(progressbar, options);

	$('.ui-dialog-content .dialogContent').on('finished', function() {
		progressbar.progressbar('value', progressbar.progressbar('option', 'max'));
		$('.start-msg', $(this)).hide();
		$('.finish-msg', $(this)).show();
	});
}

// Delete iface with ajax
function deleteIface() {
	$('#formDelIface').on('submit', async function(e) {
		e.preventDefault();

		try {
			const success = await ajaxPromiseJSON({
				url: $('#formDelIface').attr('action'),
				data: getFormValues('formDelIface'),
			});

			setSessionMessage([], success);

			location.reload();
		} catch (err) {
			displayUserMessage(err, [], 'dialog-messages');
		}
	});
}

// Reboot GESA with ajax
function rebootGesa() {
	$('#rebootConfirm').on('click', async function() {
		let timeDuration = new TimeDuration();
		const dialogContent = $(this).closest('.dialogContent');

		// Set progress bar
		const progressbar = $('#progressbar');
		const options = {
			complete: function() {
				// Complete only on reboot fail
				$('.progress-label', progressbar).text(globals.lang.ERR_REBOOT);
			}
		};

		$('.start-section', dialogContent).hide();
		$('.progress-section', dialogContent).show();

		setProgressBar(progressbar, options);

		// Block any actions on the page
		$('body').addClass('locked');

		// Start reboot & checking when restarted
		try {
			// Catch this requests errors and check if it's empty to avoid error which occure sometimes where ajax throw empty error because the server reboot before sending the response.
			try {
				await ajaxPromiseJSON({
					url: 'dialog.php',
					data: {
						action: 'reboot',
						isJSON: true,
						confirmDel: true,
					},
				});
			} catch (e) {
				if(e.length > 0)
				{
					// If error is not empty it's an error which must be handeled. Else do nothing the proccess must continue
					throw e;
				}
			}

			const success = await checkServerAvaillability(
				{   // Try 3 seconds every 5 seconds during 5 minutes (5*60)/60
					timeout: 3,
					retryIntervalSec: 5,
					maxRetries: 60,
					execNow: false,
				},
				timeDuration,
				{ url: 'index.php' },
			)
			.then(successMsg => globals.lang.GESA_RESTARTED_SUCCESS + ' ' + successMsg) // Add text to succes message
			.catch(errorMsg => { throw globals.lang.ERR_REBOOT_FAILED + ' ' + errorMsg; }); // Add text to error message
			
			setSessionMessage([], success);

			location.reload();
		}
		catch (err) {
			displayUserMessage(err, [], 'dialog-messages');

			// Change progress bar complete on failed
			progressbar.addClass('failed');
			progressbar.progressbar('value', progressbar.progressbar('option', 'max'));
		}
		finally {
			$('body').removeClass('locked');
		}
	});
}
