// interface.js

// Self called function to start on file include
(() => {
	document.addEventListener("DOMContentLoaded", () => {
		createTabsPersistant('tabs-ifaces-conf');
	});
})();

// Init function on iface tab load
function initIfaceTabForm(index, label="", isMainMgmt=false)
{
	if(isMainMgmt == false)
	{
		setSelect(
			'#index-' + index,
			{
				settings: {
					placeholderText: globals.lang.SELECT_INTERFACE || 'Select interface',
					searchText: globals.lang.SELECT_NO_INTERFACES_AVAILABLE || 'No interface available',
				},
			}
		);
		setSelect('#type-' + index);

		$('#is_vlan-' + index).on('change', function() {
			const isDisabled = !$(this).is(':checked');

			$('#vlan-' + index).prop("disabled", isDisabled);

			if(!isDisabled)
			{
				$('#vlan-' + index).trigger('focus');
			}
		});
	}

	$('#is_dhcp-' + index).on('change', function() {
		const isDisabled = $(this).is(':checked');

        $('#ip_addr-' + index).prop("disabled", isDisabled);
		$('#netmask-' + index).prop("disabled", isDisabled);
		$('#gateway-' + index).prop("disabled", isDisabled);
    });

	setFormClientValidation('.ui-tabs-panel form');
	updateIface(index, isMainMgmt);
	openDelIfaceDialog(index, label);
}

// Update interface form
function updateIface(index, isMainMgmt=false)
{
	const updateForm = $('#updateIface-' + index);
	$('#updateIface-' + index).on('submit', async e => {
		e.preventDefault();

		try {
			const formData = getFormValues('updateIface-' + index);

			const resp = await ajaxPromiseJSON({
				url: 'display.php',
				data: {
					action: 'updateIface',
					jsonKey: index.replace('_', '.'), // Replace html replacement char _ by the . used in the jsonFile
					...formData,
				},
			});

			if(resp.type == 'add')
			{
				// Reload page to refresh tabs an add new iface
				setSessionMessage([], resp.success);

				location.reload();
			}
			else if(resp.type == 'update')
			{
				// No need for refresh
				displayUserMessage([], resp.success);

				// Update current tab text with new iface label
				const currentTabId = $('#updateIface-' + index).closest('.ui-tabs-panel').attr('aria-labelledby');
				const currentTab = $('#' + currentTabId);
				if(formData?.label != currentTab.text())
				{
					currentTab.text(formData.label);
				}

				// For main managment interface if ip configuration is modified handle new url
				if(isMainMgmt == true)
				{
					// Load new url
					$('body, body *').css('cursor', 'wait');

					// Catch this request errors and check if it's empty to avoid error which occure sometimes where ajax throw empty error because the server is no longer accessible before sending the response.
					try {
						ajaxPromiseJSON({
							url: 'display.php',
							data: {
								action: 'netconfigure',
							},
						});
					} catch (e) {
						if(e.length > 0)
						{
							// If error is not empty it's an error which must be handeled. Else do nothing the proccess must continue
							throw e;
						}
					}

					if(formData?.is_dhcp != 'on')
					{
						// Not in dhcp mode because we cannot know which IP will be provided by the dhcp server
						const url = location.href.replace(location.hostname, formData.ip_addr);

						const success = await checkServerAvaillability(
							{   // Try 3 seconds every 5 seconds during 1 minutes (5*12)/60
								timeout: 3,
								retryIntervalSec: 5,
								maxRetries: 12,
								execNow: true,
							},
							{},
							{ url },
						)
						.then(successMsg => globals.lang.INTERFACE_IP_SWITCH_SUCCESS + ' ' + successMsg) // Add text to succes message
						.catch(errorMsg => { throw globals.lang.INTERFACE_IP_SWITCH_ERR + ' ' + errorMsg; }) // Add text to error message
						.finally(() => { $('body, body *').css('cursor', ''); }); // When finished remove cursor waiting style

						setSessionMessage([], success);
						
						location.assign(url);
					}
					else
					{
						// DHCP mode
						$('body, body *').css('cursor', '');
						displayUserMessage([], globals.lang.INTERFACE_DHCP_RESTART_WEB);
					}
				}
			}
		} catch (err) {
			displayUserMessage(err);
		}
	});
}

// Open delete iface confirmation dialog
function openDelIfaceDialog(index, label)
{
	$('#deleteIface-' + index).on('click', async function() {
		$(this).trigger('blur');

		openDialogByAJAX(
			'dialog.php',
			{
				action: 'deleteIface',
				jsonKey: index.replace('_', '.'),
			},
			globals.lang.DELETE + ' - ' + label,
			'dialog-info',
			{
				resizable: false,
				draggable: false,
				width: 'auto',
				position: {
					my: "right top",
					at: "right bottom",
					of: $(this),
				},
			},
		);
	});
}
